// SPDX-License-Identifier: GPL-2.0-only
/*
 * Copyright (c) 2023 Qualcomm Innovation Center, Inc. All rights reserved.
 */

#include <linux/regmap.h>
#include <linux/device.h>
#include "wcd9378-registers.h"

const u8 wcd9378_reg_access[] = {
	[WCD9378_REG(SWRS_SCP_SDCA_INTSTAT_1)]                = RD_WR_REG,
	[WCD9378_REG(SWRS_SCP_SDCA_INTSTAT_2)]                = RD_WR_REG,
	[WCD9378_REG(SWRS_SCP_SDCA_INTSTAT_3)]                = RD_WR_REG,
	[WCD9378_REG(SWRS_SCP_SDCA_INTMASK_1)]                = RD_WR_REG,
	[WCD9378_REG(SWRS_SCP_SDCA_INTMASK_2)]                = RD_WR_REG,
	[WCD9378_REG(SWRS_SCP_SDCA_INTMASK_3)]                = RD_WR_REG,
	[WCD9378_REG(SWRS_SCP_SDCA_INTRTYPE_1)]               = RD_WR_REG,
	[WCD9378_REG(SWRS_SCP_SDCA_INTRTYPE_2)]               = RD_WR_REG,
	[WCD9378_REG(SWRS_SCP_SDCA_INTRTYPE_3)]               = RD_WR_REG,
	[WCD9378_REG(WCD9378_FUNC_EXT_ID_0)]                  = RD_REG,
	[WCD9378_REG(WCD9378_FUNC_EXT_ID_1)]                  = RD_REG,
	[WCD9378_REG(WCD9378_FUNC_EXT_VER)]                   = RD_REG,
	[WCD9378_REG(WCD9378_FUNC_STAT)]                      = RD_WR_REG,
	[WCD9378_REG(WCD9378_DEV_MANU_ID_0)]                  = RD_REG,
	[WCD9378_REG(WCD9378_DEV_MANU_ID_1)]                  = RD_REG,
	[WCD9378_REG(WCD9378_DEV_PART_ID_0)]                  = RD_REG,
	[WCD9378_REG(WCD9378_DEV_PART_ID_1)]                  = RD_REG,
	[WCD9378_REG(WCD9378_DEV_VER)]                        = RD_REG,
	[WCD9378_REG(WCD9378_ANA_PAGE)]                         = RD_WR_REG,
	[WCD9378_REG(WCD9378_ANA_BIAS)]                       = RD_WR_REG,
	[WCD9378_REG(WCD9378_ANA_RX_SUPPLIES)]                = RD_WR_REG,
	[WCD9378_REG(WCD9378_ANA_HPH)]                        = RD_WR_REG,
	[WCD9378_REG(WCD9378_ANA_EAR)]                        = RD_WR_REG,
	[WCD9378_REG(WCD9378_ANA_EAR_COMPANDER_CTL)]          = RD_WR_REG,
	[WCD9378_REG(WCD9378_ANA_TX_CH1)]                     = RD_WR_REG,
	[WCD9378_REG(WCD9378_ANA_TX_CH2)]                     = RD_WR_REG,
	[WCD9378_REG(WCD9378_ANA_TX_CH3)]                     = RD_WR_REG,
	[WCD9378_REG(WCD9378_ANA_TX_CH3_HPF)]                 = RD_WR_REG,
	[WCD9378_REG(WCD9378_ANA_MICB1_MICB2_DSP_EN_LOGIC)]   = RD_WR_REG,
	[WCD9378_REG(WCD9378_ANA_MICB3_DSP_EN_LOGIC)]         = RD_WR_REG,
	[WCD9378_REG(WCD9378_ANA_MBHC_MECH)]                  = RD_WR_REG,
	[WCD9378_REG(WCD9378_ANA_MBHC_ELECT)]                 = RD_WR_REG,
	[WCD9378_REG(WCD9378_ANA_MBHC_ZDET)]                  = RD_WR_REG,
	[WCD9378_REG(WCD9378_ANA_MBHC_RESULT_1)]              = RD_REG,
	[WCD9378_REG(WCD9378_ANA_MBHC_RESULT_2)]              = RD_REG,
	[WCD9378_REG(WCD9378_ANA_MBHC_RESULT_3)]              = RD_REG,
	[WCD9378_REG(WCD9378_ANA_MBHC_BTN0)]                  = RD_WR_REG,
	[WCD9378_REG(WCD9378_ANA_MBHC_BTN1)]                  = RD_WR_REG,
	[WCD9378_REG(WCD9378_ANA_MBHC_BTN2)]                  = RD_WR_REG,
	[WCD9378_REG(WCD9378_ANA_MBHC_BTN3)]                  = RD_WR_REG,
	[WCD9378_REG(WCD9378_ANA_MBHC_BTN4)]                  = RD_WR_REG,
	[WCD9378_REG(WCD9378_ANA_MBHC_BTN5)]                  = RD_WR_REG,
	[WCD9378_REG(WCD9378_ANA_MBHC_BTN6)]                  = RD_WR_REG,
	[WCD9378_REG(WCD9378_ANA_MBHC_BTN7)]                  = RD_WR_REG,
	[WCD9378_REG(WCD9378_ANA_MICB1)]                      = RD_WR_REG,
	[WCD9378_REG(WCD9378_ANA_MICB2)]                      = RD_WR_REG,
	[WCD9378_REG(WCD9378_ANA_MICB2_RAMP)]                 = RD_WR_REG,
	[WCD9378_REG(WCD9378_ANA_MICB3)]                      = RD_WR_REG,
	[WCD9378_REG(WCD9378_BIAS_CTL)]                       = RD_WR_REG,
	[WCD9378_REG(WCD9378_BIAS_VBG_FINE_ADJ)]              = RD_WR_REG,
	[WCD9378_REG(WCD9378_LDOL_VDDCX_ADJUST)]              = RD_WR_REG,
	[WCD9378_REG(WCD9378_LDOL_DISABLE_LDOL)]              = RD_WR_REG,
	[WCD9378_REG(WCD9378_MBHC_CTL_CLK)]                   = RD_WR_REG,
	[WCD9378_REG(WCD9378_MBHC_CTL_ANA)]                   = RD_WR_REG,
	[WCD9378_REG(WCD9378_MBHC_CTL_SPARE_1)]               = RD_WR_REG,
	[WCD9378_REG(WCD9378_MBHC_CTL_SPARE_2)]               = RD_WR_REG,
	[WCD9378_REG(WCD9378_MBHC_CTL_BCS)]                   = RD_WR_REG,
	[WCD9378_REG(WCD9378_MBHC_MOISTURE_DET_FSM_STATUS)]   = RD_REG,
	[WCD9378_REG(WCD9378_MBHC_TEST_CTL)]                  = RD_WR_REG,
	[WCD9378_REG(WCD9378_LDOH_MODE)]                      = RD_WR_REG,
	[WCD9378_REG(WCD9378_LDOH_BIAS)]                      = RD_WR_REG,
	[WCD9378_REG(WCD9378_LDOH_STB_LOADS)]                 = RD_WR_REG,
	[WCD9378_REG(WCD9378_LDOH_SLOWRAMP)]                  = RD_WR_REG,
	[WCD9378_REG(WCD9378_MICB1_TEST_CTL_1)]               = RD_WR_REG,
	[WCD9378_REG(WCD9378_MICB1_TEST_CTL_2)]               = RD_WR_REG,
	[WCD9378_REG(WCD9378_MICB1_TEST_CTL_3)]               = RD_WR_REG,
	[WCD9378_REG(WCD9378_MICB2_TEST_CTL_1)]               = RD_WR_REG,
	[WCD9378_REG(WCD9378_MICB2_TEST_CTL_2)]               = RD_WR_REG,
	[WCD9378_REG(WCD9378_MICB2_TEST_CTL_3)]               = RD_WR_REG,
	[WCD9378_REG(WCD9378_MICB3_TEST_CTL_1)]               = RD_WR_REG,
	[WCD9378_REG(WCD9378_MICB3_TEST_CTL_2)]               = RD_WR_REG,
	[WCD9378_REG(WCD9378_MICB3_TEST_CTL_3)]               = RD_WR_REG,
	[WCD9378_REG(WCD9378_TX_COM_ADC_VCM)]                 = RD_WR_REG,
	[WCD9378_REG(WCD9378_TX_COM_BIAS_ATEST)]              = RD_WR_REG,
	[WCD9378_REG(WCD9378_TX_COM_SPARE1)]                  = RD_WR_REG,
	[WCD9378_REG(WCD9378_TX_COM_SPARE2)]                  = RD_WR_REG,
	[WCD9378_REG(WCD9378_TX_COM_TXFE_DIV_CTL)]            = RD_WR_REG,
	[WCD9378_REG(WCD9378_TX_COM_TXFE_DIV_START)]          = RD_WR_REG,
	[WCD9378_REG(WCD9378_TX_COM_SPARE3)]                  = RD_WR_REG,
	[WCD9378_REG(WCD9378_TX_COM_SPARE4)]                  = RD_WR_REG,
	[WCD9378_REG(WCD9378_TX_1_2_TEST_EN)]                 = RD_WR_REG,
	[WCD9378_REG(WCD9378_TX_1_2_ADC_IB)]                  = RD_WR_REG,
	[WCD9378_REG(WCD9378_TX_1_2_ATEST_REFCTL)]            = RD_WR_REG,
	[WCD9378_REG(WCD9378_TX_1_2_TEST_CTL)]                = RD_WR_REG,
	[WCD9378_REG(WCD9378_TX_1_2_TEST_BLK_EN1)]            = RD_WR_REG,
	[WCD9378_REG(WCD9378_TX_1_2_TXFE1_CLKDIV)]            = RD_WR_REG,
	[WCD9378_REG(WCD9378_TX_1_2_SAR2_ERR)]                = RD_REG,
	[WCD9378_REG(WCD9378_TX_1_2_SAR1_ERR)]                = RD_REG,
	[WCD9378_REG(WCD9378_TX_3_TEST_EN)]                   = RD_WR_REG,
	[WCD9378_REG(WCD9378_TX_3_ADC_IB)]                    = RD_WR_REG,
	[WCD9378_REG(WCD9378_TX_3_ATEST_REFCTL)]              = RD_WR_REG,
	[WCD9378_REG(WCD9378_TX_3_TEST_CTL)]                  = RD_WR_REG,
	[WCD9378_REG(WCD9378_TX_3_TEST_BLK_EN3)]              = RD_WR_REG,
	[WCD9378_REG(WCD9378_TX_3_TXFE3_CLKDIV)]              = RD_WR_REG,
	[WCD9378_REG(WCD9378_TX_3_SAR4_ERR)]                  = RD_REG,
	[WCD9378_REG(WCD9378_TX_3_SAR3_ERR)]                  = RD_REG,
	[WCD9378_REG(WCD9378_TX_3_TEST_BLK_EN2)]              = RD_WR_REG,
	[WCD9378_REG(WCD9378_TX_3_TXFE2_CLKDIV)]              = RD_WR_REG,
	[WCD9378_REG(WCD9378_TX_3_SPARE1)]                    = RD_WR_REG,
	[WCD9378_REG(WCD9378_TX_3_TEST_BLK_EN4)]              = RD_WR_REG,
	[WCD9378_REG(WCD9378_TX_3_SPARE2)]                    = RD_WR_REG,
	[WCD9378_REG(WCD9378_TX_3_SPARE3)]                    = RD_WR_REG,
	[WCD9378_REG(WCD9378_RX_AUX_SW_CTL)]                  = RD_WR_REG,
	[WCD9378_REG(WCD9378_RX_PA_AUX_IN_CONN)]              = RD_WR_REG,
	[WCD9378_REG(WCD9378_RX_TIMER_DIV)]                   = RD_WR_REG,
	[WCD9378_REG(WCD9378_RX_OCP_CTL)]                     = RD_WR_REG,
	[WCD9378_REG(WCD9378_RX_OCP_COUNT)]                   = RD_WR_REG,
	[WCD9378_REG(WCD9378_RX_BIAS_EAR_DAC)]                = RD_WR_REG,
	[WCD9378_REG(WCD9378_RX_BIAS_EAR_AMP)]                = RD_WR_REG,
	[WCD9378_REG(WCD9378_RX_BIAS_HPH_LDO)]                = RD_WR_REG,
	[WCD9378_REG(WCD9378_RX_BIAS_HPH_PA)]                 = RD_WR_REG,
	[WCD9378_REG(WCD9378_RX_BIAS_HPH_RDACBUFF_CNP2)]      = RD_WR_REG,
	[WCD9378_REG(WCD9378_RX_BIAS_HPH_RDAC_LDO)]           = RD_WR_REG,
	[WCD9378_REG(WCD9378_RX_BIAS_HPH_CNP1)]               = RD_WR_REG,
	[WCD9378_REG(WCD9378_RX_BIAS_HPH_LOWPOWER)]           = RD_WR_REG,
	[WCD9378_REG(WCD9378_RX_BIAS_AUX_DAC)]                = RD_WR_REG,
	[WCD9378_REG(WCD9378_RX_BIAS_AUX_AMP)]                = RD_WR_REG,
	[WCD9378_REG(WCD9378_RX_SPARE_1)]                     = RD_WR_REG,
	[WCD9378_REG(WCD9378_RX_SPARE_2)]                     = RD_WR_REG,
	[WCD9378_REG(WCD9378_RX_SPARE_3)]                     = RD_WR_REG,
	[WCD9378_REG(WCD9378_RX_SPARE_4)]                     = RD_WR_REG,
	[WCD9378_REG(WCD9378_RX_SPARE_5)]                     = RD_WR_REG,
	[WCD9378_REG(WCD9378_RX_SPARE_6)]                     = RD_WR_REG,
	[WCD9378_REG(WCD9378_RX_SPARE_7)]                     = RD_WR_REG,
	[WCD9378_REG(WCD9378_HPH_L_STATUS)]                   = RD_REG,
	[WCD9378_REG(WCD9378_HPH_R_STATUS)]                   = RD_REG,
	[WCD9378_REG(WCD9378_HPH_CNP_EN)]                     = RD_WR_REG,
	[WCD9378_REG(WCD9378_HPH_CNP_WG_CTL)]                 = RD_WR_REG,
	[WCD9378_REG(WCD9378_HPH_CNP_WG_TIME)]                = RD_WR_REG,
	[WCD9378_REG(WCD9378_HPH_OCP_CTL)]                    = RD_WR_REG,
	[WCD9378_REG(WCD9378_HPH_AUTO_CHOP)]                  = RD_WR_REG,
	[WCD9378_REG(WCD9378_HPH_CHOP_CTL)]                   = RD_WR_REG,
	[WCD9378_REG(WCD9378_HPH_PA_CTL1)]                    = RD_WR_REG,
	[WCD9378_REG(WCD9378_HPH_PA_CTL2)]                    = RD_WR_REG,
	[WCD9378_REG(WCD9378_HPH_L_EN)]                       = RD_WR_REG,
	[WCD9378_REG(WCD9378_HPH_L_TEST)]                     = RD_WR_REG,
	[WCD9378_REG(WCD9378_HPH_L_ATEST)]                    = RD_WR_REG,
	[WCD9378_REG(WCD9378_HPH_R_EN)]                       = RD_WR_REG,
	[WCD9378_REG(WCD9378_HPH_R_TEST)]                     = RD_WR_REG,
	[WCD9378_REG(WCD9378_HPH_R_ATEST)]                    = RD_WR_REG,
	[WCD9378_REG(WCD9378_HPH_RDAC_CLK_CTL1)]              = RD_WR_REG,
	[WCD9378_REG(WCD9378_HPH_RDAC_CLK_CTL2)]              = RD_WR_REG,
	[WCD9378_REG(WCD9378_HPH_RDAC_LDO_CTL)]               = RD_WR_REG,
	[WCD9378_REG(WCD9378_HPH_RDAC_CHOP_CLK_LP_CTL)]       = RD_WR_REG,
	[WCD9378_REG(WCD9378_HPH_REFBUFF_UHQA_CTL)]           = RD_WR_REG,
	[WCD9378_REG(WCD9378_HPH_REFBUFF_LP_CTL)]             = RD_WR_REG,
	[WCD9378_REG(WCD9378_HPH_L_DAC_CTL)]                  = RD_WR_REG,
	[WCD9378_REG(WCD9378_HPH_R_DAC_CTL)]                  = RD_WR_REG,
	[WCD9378_REG(WCD9378_HPH_SURGE_HPHLR_SURGE_COMP_SEL)] = RD_WR_REG,
	[WCD9378_REG(WCD9378_HPH_SURGE_HPHLR_SURGE_EN)]       = RD_WR_REG,
	[WCD9378_REG(WCD9378_HPH_SURGE_HPHLR_SURGE_MISC1)]    = RD_WR_REG,
	[WCD9378_REG(WCD9378_HPH_SURGE_HPHLR_SURGE_STATUS)]   = RD_REG,
	[WCD9378_REG(WCD9378_EAR_EAR_EN_REG)]                 = RD_WR_REG,
	[WCD9378_REG(WCD9378_EAR_EAR_PA_CON)]                 = RD_WR_REG,
	[WCD9378_REG(WCD9378_EAR_EAR_SP_CON)]                 = RD_WR_REG,
	[WCD9378_REG(WCD9378_EAR_EAR_DAC_CON)]                = RD_WR_REG,
	[WCD9378_REG(WCD9378_EAR_EAR_CNP_FSM_CON)]            = RD_WR_REG,
	[WCD9378_REG(WCD9378_EAR_TEST_CTL)]                   = RD_WR_REG,
	[WCD9378_REG(WCD9378_EAR_STATUS_REG_1)]               = RD_REG,
	[WCD9378_REG(WCD9378_EAR_STATUS_REG_2)]               = RD_REG,
	[WCD9378_REG(WCD9378_ANA_NEW_PAGE)]                         = RD_WR_REG,
	[WCD9378_REG(WCD9378_HPH_NEW_ANA_HPH2)]               = RD_WR_REG,
	[WCD9378_REG(WCD9378_HPH_NEW_ANA_HPH3)]               = RD_WR_REG,
	[WCD9378_REG(WCD9378_SLEEP_CTL)]                      = RD_WR_REG,
	[WCD9378_REG(WCD9378_SLEEP_WATCHDOG_CTL)]             = RD_WR_REG,
	[WCD9378_REG(WCD9378_MBHC_NEW_ELECT_REM_CLAMP_CTL)]   = RD_WR_REG,
	[WCD9378_REG(WCD9378_MBHC_NEW_CTL_1)]                 = RD_WR_REG,
	[WCD9378_REG(WCD9378_MBHC_NEW_CTL_2)]                 = RD_WR_REG,
	[WCD9378_REG(WCD9378_MBHC_NEW_PLUG_DETECT_CTL)]       = RD_WR_REG,
	[WCD9378_REG(WCD9378_MBHC_NEW_ZDET_ANA_CTL)]          = RD_WR_REG,
	[WCD9378_REG(WCD9378_MBHC_NEW_ZDET_RAMP_CTL)]         = RD_WR_REG,
	[WCD9378_REG(WCD9378_MBHC_NEW_FSM_STATUS)]            = RD_REG,
	[WCD9378_REG(WCD9378_MBHC_NEW_ADC_RESULT)]            = RD_REG,
	[WCD9378_REG(WCD9378_AUX_AUXPA)]                      = RD_WR_REG,
	[WCD9378_REG(WCD9378_DIE_CRACK_DIE_CRK_DET_EN)]       = RD_WR_REG,
	[WCD9378_REG(WCD9378_DIE_CRACK_DIE_CRK_DET_OUT)]      = RD_REG,
	[WCD9378_REG(WCD9378_TX_NEW_TX_CH12_MUX)]             = RD_WR_REG,
	[WCD9378_REG(WCD9378_TX_NEW_TX_CH34_MUX)]             = RD_WR_REG,
	[WCD9378_REG(WCD9378_HPH_NEW_INT_RDAC_GAIN_CTL)]      = RD_WR_REG,
	[WCD9378_REG(WCD9378_HPH_NEW_INT_RDAC_HD2_CTL_L)]     = RD_WR_REG,
	[WCD9378_REG(WCD9378_HPH_NEW_INT_RDAC_VREF_CTL)]      = RD_WR_REG,
	[WCD9378_REG(WCD9378_HPH_NEW_INT_RDAC_OVERRIDE_CTL)]  = RD_WR_REG,
	[WCD9378_REG(WCD9378_HPH_NEW_INT_RDAC_HD2_CTL_R)]     = RD_WR_REG,
	[WCD9378_REG(WCD9378_HPH_NEW_INT_PA_MISC1)]           = RD_WR_REG,
	[WCD9378_REG(WCD9378_HPH_NEW_INT_PA_MISC2)]           = RD_WR_REG,
	[WCD9378_REG(WCD9378_HPH_NEW_INT_PA_RDAC_MISC)]       = RD_WR_REG,
	[WCD9378_REG(WCD9378_HPH_NEW_INT_HPH_TIMER1)]         = RD_WR_REG,
	[WCD9378_REG(WCD9378_HPH_NEW_INT_HPH_TIMER2)]         = RD_WR_REG,
	[WCD9378_REG(WCD9378_HPH_NEW_INT_HPH_TIMER3)]         = RD_WR_REG,
	[WCD9378_REG(WCD9378_HPH_NEW_INT_HPH_TIMER4)]         = RD_WR_REG,
	[WCD9378_REG(WCD9378_HPH_NEW_INT_PA_RDAC_MISC2)]      = RD_WR_REG,
	[WCD9378_REG(WCD9378_HPH_NEW_INT_PA_RDAC_MISC3)]      = RD_WR_REG,
	[WCD9378_REG(WCD9378_RX_NEW_INT_HPH_RDAC_BIAS_LOHIFI)] = RD_WR_REG,
	[WCD9378_REG(WCD9378_RX_NEW_INT_HPH_RDAC_BIAS_ULP)]   = RD_WR_REG,
	[WCD9378_REG(WCD9378_RX_NEW_INT_HPH_RDAC_LDO_LP)]     = RD_WR_REG,
	[WCD9378_REG(WCD9378_CP_CLASSG_CP_CTRL_0)]            = RD_WR_REG,
	[WCD9378_REG(WCD9378_CP_CLASSG_CP_CTRL_1)]            = RD_WR_REG,
	[WCD9378_REG(WCD9378_CP_CLASSG_CP_CTRL_2)]            = RD_WR_REG,
	[WCD9378_REG(WCD9378_CP_CLASSG_CP_CTRL_3)]            = RD_WR_REG,
	[WCD9378_REG(WCD9378_CP_CLASSG_CP_CTRL_4)]            = RD_WR_REG,
	[WCD9378_REG(WCD9378_CP_CLASSG_CP_CTRL_5)]            = RD_WR_REG,
	[WCD9378_REG(WCD9378_CP_CLASSG_CP_CTRL_6)]            = RD_WR_REG,
	[WCD9378_REG(WCD9378_CP_CLASSG_CP_CTRL_7)]            = RD_WR_REG,
	[WCD9378_REG(WCD9378_CP_VNEGDAC_CTRL_0)]              = RD_WR_REG,
	[WCD9378_REG(WCD9378_CP_VNEGDAC_CTRL_1)]              = RD_WR_REG,
	[WCD9378_REG(WCD9378_CP_VNEGDAC_CTRL_2)]              = RD_WR_REG,
	[WCD9378_REG(WCD9378_CP_VNEGDAC_CTRL_3)]              = RD_WR_REG,
	[WCD9378_REG(WCD9378_CP_CP_DTOP_CTRL_0)]              = RD_WR_REG,
	[WCD9378_REG(WCD9378_CP_CP_DTOP_CTRL_1)]              = RD_WR_REG,
	[WCD9378_REG(WCD9378_CP_CP_DTOP_CTRL_2)]              = RD_WR_REG,
	[WCD9378_REG(WCD9378_CP_CP_DTOP_CTRL_3)]              = RD_WR_REG,
	[WCD9378_REG(WCD9378_CP_CP_DTOP_CTRL_4)]              = RD_WR_REG,
	[WCD9378_REG(WCD9378_CP_CP_DTOP_CTRL_5)]              = RD_WR_REG,
	[WCD9378_REG(WCD9378_CP_CP_DTOP_CTRL_6)]              = RD_WR_REG,
	[WCD9378_REG(WCD9378_CP_CP_DTOP_CTRL_7)]              = RD_WR_REG,
	[WCD9378_REG(WCD9378_CP_CP_DTOP_CTRL_8)]              = RD_WR_REG,
	[WCD9378_REG(WCD9378_CP_CP_DTOP_CTRL_9)]              = RD_WR_REG,
	[WCD9378_REG(WCD9378_CP_CP_DTOP_CTRL_10)]             = RD_WR_REG,
	[WCD9378_REG(WCD9378_CP_CP_DTOP_CTRL_11)]             = RD_WR_REG,
	[WCD9378_REG(WCD9378_CP_CP_DTOP_CTRL_12)]             = RD_WR_REG,
	[WCD9378_REG(WCD9378_CP_CP_DTOP_CTRL_13)]             = RD_WR_REG,
	[WCD9378_REG(WCD9378_CP_CP_DTOP_CTRL_14)]             = RD_WR_REG,
	[WCD9378_REG(WCD9378_CP_CP_DTOP_CTRL_15)]             = RD_WR_REG,
	[WCD9378_REG(WCD9378_CP_CP_DTOP_CTRL_16)]             = RD_WR_REG,
	[WCD9378_REG(WCD9378_CP_CP_DTOP_CTRL_17)]             = RD_WR_REG,
	[WCD9378_REG(WCD9378_CP_CP_DTOP_CTRL_18)]             = RD_WR_REG,
	[WCD9378_REG(WCD9378_CP_CP_DTOP_CTRL_19)]             = RD_WR_REG,
	[WCD9378_REG(WCD9378_MBHC_NEW_INT_MOISTURE_DET_DC_CTRL)] = RD_WR_REG,
	[WCD9378_REG(WCD9378_MBHC_NEW_INT_MOISTURE_DET_POLLING_CTRL)] = RD_WR_REG,
	[WCD9378_REG(WCD9378_MBHC_NEW_INT_MECH_DET_CURRENT)]  = RD_WR_REG,
	[WCD9378_REG(WCD9378_MBHC_NEW_INT_SPARE_2)]           = RD_WR_REG,
	[WCD9378_REG(WCD9378_EAR_INT_NEW_EAR_CHOPPER_CON)]    = RD_WR_REG,
	[WCD9378_REG(WCD9378_EAR_INT_NEW_CNP_VCM_CON1)]       = RD_WR_REG,
	[WCD9378_REG(WCD9378_EAR_INT_NEW_CNP_VCM_CON2)]       = RD_WR_REG,
	[WCD9378_REG(WCD9378_EAR_INT_NEW_EAR_DYNAMIC_BIAS)]   = RD_WR_REG,
	[WCD9378_REG(WCD9378_AUX_INT_EN_REG)]                 = RD_WR_REG,
	[WCD9378_REG(WCD9378_AUX_INT_PA_CTRL)]                = RD_WR_REG,
	[WCD9378_REG(WCD9378_AUX_INT_SP_CTRL)]                = RD_WR_REG,
	[WCD9378_REG(WCD9378_AUX_INT_DAC_CTRL)]               = RD_WR_REG,
	[WCD9378_REG(WCD9378_AUX_INT_CLK_CTRL)]               = RD_WR_REG,
	[WCD9378_REG(WCD9378_AUX_INT_TEST_CTRL)]              = RD_WR_REG,
	[WCD9378_REG(WCD9378_AUX_INT_STATUS_REG)]             = RD_REG,
	[WCD9378_REG(WCD9378_AUX_INT_MISC)]                   = RD_WR_REG,
	[WCD9378_REG(WCD9378_SLEEP_INT_WATCHDOG_CTL_1)]       = RD_WR_REG,
	[WCD9378_REG(WCD9378_SLEEP_INT_WATCHDOG_CTL_2)]       = RD_WR_REG,
	[WCD9378_REG(WCD9378_DIE_CRACK_INT_DIE_CRK_DET_INT1)] = RD_WR_REG,
	[WCD9378_REG(WCD9378_DIE_CRACK_INT_DIE_CRK_DET_INT2)] = RD_WR_REG,
	[WCD9378_REG(WCD9378_TX_COM_NEW_INT_TXFE_DIVSTOP_L2)] = RD_WR_REG,
	[WCD9378_REG(WCD9378_TX_COM_NEW_INT_TXFE_DIVSTOP_L1)] = RD_WR_REG,
	[WCD9378_REG(WCD9378_TX_COM_NEW_INT_TXFE_DIVSTOP_L0)] = RD_WR_REG,
	[WCD9378_REG(WCD9378_TX_COM_NEW_INT_SPARE1)]          = RD_WR_REG,
	[WCD9378_REG(WCD9378_TX_COM_NEW_INT_SPARE2)]          = RD_WR_REG,
	[WCD9378_REG(WCD9378_TX_COM_NEW_INT_TXFE_NINIT_L2)]   = RD_WR_REG,
	[WCD9378_REG(WCD9378_TX_COM_NEW_INT_TXFE_NINIT_L1)]   = RD_WR_REG,
	[WCD9378_REG(WCD9378_TX_COM_NEW_INT_TXFE_NINIT_L0)]   = RD_WR_REG,
	[WCD9378_REG(WCD9378_TX_COM_NEW_INT_SPARE3)]          = RD_WR_REG,
	[WCD9378_REG(WCD9378_TX_COM_NEW_INT_SPARE4)]          = RD_WR_REG,
	[WCD9378_REG(WCD9378_TX_COM_NEW_INT_SPARE5)]          = RD_WR_REG,
	[WCD9378_REG(WCD9378_TX_COM_NEW_INT_SPARE6)]          = RD_WR_REG,
	[WCD9378_REG(WCD9378_TX_COM_NEW_INT_SPARE7)]          = RD_WR_REG,
	[WCD9378_REG(WCD9378_TX_COM_NEW_INT_TXADC_SCBIAS_L2L1)] = RD_WR_REG,
	[WCD9378_REG(WCD9378_TX_COM_NEW_INT_TXADC_SCBIAS_L0)] = RD_WR_REG,
	[WCD9378_REG(WCD9378_TX_COM_NEW_INT_TXADC_INT_L2)]    = RD_WR_REG,
	[WCD9378_REG(WCD9378_TX_COM_NEW_INT_TXADC_INT_L1)]    = RD_WR_REG,
	[WCD9378_REG(WCD9378_TX_COM_NEW_INT_TXADC_INT_L0)]    = RD_WR_REG,
	[WCD9378_REG(WCD9378_TX_COM_NEW_INT_SPARE8)]          = RD_WR_REG,
	[WCD9378_REG(WCD9378_TAMBORA_PAGE)]                   = RD_WR_REG,
	[WCD9378_REG(WCD9378_CHIP_ID0)]                       = RD_REG,
	[WCD9378_REG(WCD9378_CHIP_ID1)]                       = RD_REG,
	[WCD9378_REG(WCD9378_CHIP_ID2)]                       = RD_REG,
	[WCD9378_REG(WCD9378_CHIP_ID3)]                       = RD_REG,
	[WCD9378_REG(WCD9378_SWR_TX_CLK_RATE)]                = RD_WR_REG,
	[WCD9378_REG(WCD9378_CDC_RST_CTL)]                    = RD_WR_REG,
	[WCD9378_REG(WCD9378_TOP_CLK_CFG)]                    = RD_WR_REG,
	[WCD9378_REG(WCD9378_CDC_ANA_CLK_CTL)]                = RD_WR_REG,
	[WCD9378_REG(WCD9378_CDC_DIG_CLK_CTL)]                = RD_WR_REG,
	[WCD9378_REG(WCD9378_SWR_RST_EN)]                     = RD_WR_REG,
	[WCD9378_REG(WCD9378_CDC_PATH_MODE)]                  = RD_WR_REG,
	[WCD9378_REG(WCD9378_CDC_RX_RST)]                     = RD_WR_REG,
	[WCD9378_REG(WCD9378_CDC_RX0_CTL)]                    = RD_WR_REG,
	[WCD9378_REG(WCD9378_CDC_RX1_CTL)]                    = RD_WR_REG,
	[WCD9378_REG(WCD9378_CDC_RX2_CTL)]                    = RD_WR_REG,
	[WCD9378_REG(WCD9378_CDC_TX_ANA_MODE_0_1)]            = RD_WR_REG,
	[WCD9378_REG(WCD9378_CDC_TX_ANA_MODE_2_3)]            = RD_WR_REG,
	[WCD9378_REG(WCD9378_CDC_COMP_CTL_0)]                 = RD_WR_REG,
	[WCD9378_REG(WCD9378_CDC_ANA_TX_CLK_CTL)]             = RD_WR_REG,
	[WCD9378_REG(WCD9378_CDC_HPH_DSM_A1_0)]               = RD_WR_REG,
	[WCD9378_REG(WCD9378_CDC_HPH_DSM_A1_1)]               = RD_WR_REG,
	[WCD9378_REG(WCD9378_CDC_HPH_DSM_A2_0)]               = RD_WR_REG,
	[WCD9378_REG(WCD9378_CDC_HPH_DSM_A2_1)]               = RD_WR_REG,
	[WCD9378_REG(WCD9378_CDC_HPH_DSM_A3_0)]               = RD_WR_REG,
	[WCD9378_REG(WCD9378_CDC_HPH_DSM_A3_1)]               = RD_WR_REG,
	[WCD9378_REG(WCD9378_CDC_HPH_DSM_A4_0)]               = RD_WR_REG,
	[WCD9378_REG(WCD9378_CDC_HPH_DSM_A4_1)]               = RD_WR_REG,
	[WCD9378_REG(WCD9378_CDC_HPH_DSM_A5_0)]               = RD_WR_REG,
	[WCD9378_REG(WCD9378_CDC_HPH_DSM_A5_1)]               = RD_WR_REG,
	[WCD9378_REG(WCD9378_CDC_HPH_DSM_A6_0)]               = RD_WR_REG,
	[WCD9378_REG(WCD9378_CDC_HPH_DSM_A7_0)]               = RD_WR_REG,
	[WCD9378_REG(WCD9378_CDC_HPH_DSM_C_0)]                = RD_WR_REG,
	[WCD9378_REG(WCD9378_CDC_HPH_DSM_C_1)]                = RD_WR_REG,
	[WCD9378_REG(WCD9378_CDC_HPH_DSM_C_2)]                = RD_WR_REG,
	[WCD9378_REG(WCD9378_CDC_HPH_DSM_C_3)]                = RD_WR_REG,
	[WCD9378_REG(WCD9378_CDC_HPH_DSM_R1)]                 = RD_WR_REG,
	[WCD9378_REG(WCD9378_CDC_HPH_DSM_R2)]                 = RD_WR_REG,
	[WCD9378_REG(WCD9378_CDC_HPH_DSM_R3)]                 = RD_WR_REG,
	[WCD9378_REG(WCD9378_CDC_HPH_DSM_R4)]                 = RD_WR_REG,
	[WCD9378_REG(WCD9378_CDC_HPH_DSM_R5)]                 = RD_WR_REG,
	[WCD9378_REG(WCD9378_CDC_HPH_DSM_R6)]                 = RD_WR_REG,
	[WCD9378_REG(WCD9378_CDC_HPH_DSM_R7)]                 = RD_WR_REG,
	[WCD9378_REG(WCD9378_CDC_AUX_DSM_A1_0)]               = RD_WR_REG,
	[WCD9378_REG(WCD9378_CDC_AUX_DSM_A1_1)]               = RD_WR_REG,
	[WCD9378_REG(WCD9378_CDC_AUX_DSM_A2_0)]               = RD_WR_REG,
	[WCD9378_REG(WCD9378_CDC_AUX_DSM_A2_1)]               = RD_WR_REG,
	[WCD9378_REG(WCD9378_CDC_AUX_DSM_A3_0)]               = RD_WR_REG,
	[WCD9378_REG(WCD9378_CDC_AUX_DSM_A3_1)]               = RD_WR_REG,
	[WCD9378_REG(WCD9378_CDC_AUX_DSM_A4_0)]               = RD_WR_REG,
	[WCD9378_REG(WCD9378_CDC_AUX_DSM_A4_1)]               = RD_WR_REG,
	[WCD9378_REG(WCD9378_CDC_AUX_DSM_A5_0)]               = RD_WR_REG,
	[WCD9378_REG(WCD9378_CDC_AUX_DSM_A5_1)]               = RD_WR_REG,
	[WCD9378_REG(WCD9378_CDC_AUX_DSM_A6_0)]               = RD_WR_REG,
	[WCD9378_REG(WCD9378_CDC_AUX_DSM_A7_0)]               = RD_WR_REG,
	[WCD9378_REG(WCD9378_CDC_AUX_DSM_C_0)]                = RD_WR_REG,
	[WCD9378_REG(WCD9378_CDC_AUX_DSM_C_1)]                = RD_WR_REG,
	[WCD9378_REG(WCD9378_CDC_AUX_DSM_C_2)]                = RD_WR_REG,
	[WCD9378_REG(WCD9378_CDC_AUX_DSM_C_3)]                = RD_WR_REG,
	[WCD9378_REG(WCD9378_CDC_AUX_DSM_R1)]                 = RD_WR_REG,
	[WCD9378_REG(WCD9378_CDC_AUX_DSM_R2)]                 = RD_WR_REG,
	[WCD9378_REG(WCD9378_CDC_AUX_DSM_R3)]                 = RD_WR_REG,
	[WCD9378_REG(WCD9378_CDC_AUX_DSM_R4)]                 = RD_WR_REG,
	[WCD9378_REG(WCD9378_CDC_AUX_DSM_R5)]                 = RD_WR_REG,
	[WCD9378_REG(WCD9378_CDC_AUX_DSM_R6)]                 = RD_WR_REG,
	[WCD9378_REG(WCD9378_CDC_AUX_DSM_R7)]                 = RD_WR_REG,
	[WCD9378_REG(WCD9378_CDC_HPH_GAIN_RX_0)]              = RD_WR_REG,
	[WCD9378_REG(WCD9378_CDC_HPH_GAIN_RX_1)]              = RD_WR_REG,
	[WCD9378_REG(WCD9378_CDC_HPH_GAIN_DSD_0)]             = RD_WR_REG,
	[WCD9378_REG(WCD9378_CDC_HPH_GAIN_DSD_1)]             = RD_WR_REG,
	[WCD9378_REG(WCD9378_CDC_HPH_GAIN_DSD_2)]             = RD_WR_REG,
	[WCD9378_REG(WCD9378_CDC_AUX_GAIN_DSD_0)]             = RD_WR_REG,
	[WCD9378_REG(WCD9378_CDC_AUX_GAIN_DSD_1)]             = RD_WR_REG,
	[WCD9378_REG(WCD9378_CDC_AUX_GAIN_DSD_2)]             = RD_WR_REG,
	[WCD9378_REG(WCD9378_CDC_HPH_GAIN_CTL)]               = RD_WR_REG,
	[WCD9378_REG(WCD9378_CDC_AUX_GAIN_CTL)]               = RD_WR_REG,
	[WCD9378_REG(WCD9378_CDC_PATH_CTL)]                   = RD_WR_REG,
	[WCD9378_REG(WCD9378_CDC_SWR_CLG)]                    = RD_WR_REG,
	[WCD9378_REG(WCD9378_SWR_CLG_BYP)]                    = RD_WR_REG,
	[WCD9378_REG(WCD9378_CDC_TX0_CTL)]                    = RD_WR_REG,
	[WCD9378_REG(WCD9378_CDC_TX1_CTL)]                    = RD_WR_REG,
	[WCD9378_REG(WCD9378_CDC_TX2_CTL)]                    = RD_WR_REG,
	[WCD9378_REG(WCD9378_CDC_TX_RST)]                     = RD_WR_REG,
	[WCD9378_REG(WCD9378_CDC_REQ_CTL)]                    = RD_WR_REG,
	[WCD9378_REG(WCD9378_CDC_RST)]                        = RD_WR_REG,
	[WCD9378_REG(WCD9378_CDC_AMIC_CTL)]                   = RD_WR_REG,
	[WCD9378_REG(WCD9378_CDC_DMIC_CTL)]                   = RD_WR_REG,
	[WCD9378_REG(WCD9378_CDC_DMIC1_CTL)]                  = RD_WR_REG,
	[WCD9378_REG(WCD9378_CDC_DMIC2_CTL)]                  = RD_WR_REG,
	[WCD9378_REG(WCD9378_CDC_DMIC3_CTL)]                  = RD_WR_REG,
	[WCD9378_REG(WCD9378_EFUSE_PRG_CTL)]                  = RD_WR_REG,
	[WCD9378_REG(WCD9378_EFUSE_CTL)]                      = RD_WR_REG,
	[WCD9378_REG(WCD9378_CDC_DMIC_RATE_1_2)]              = RD_WR_REG,
	[WCD9378_REG(WCD9378_CDC_DMIC_RATE_3_4)]              = RD_WR_REG,
	[WCD9378_REG(WCD9378_PDM_WD_EN_OVRD)]                 = RD_WR_REG,
	[WCD9378_REG(WCD9378_PDM_WD_CTL0)]                    = RD_WR_REG,
	[WCD9378_REG(WCD9378_PDM_WD_CTL1)]                    = RD_WR_REG,
	[WCD9378_REG(WCD9378_PDM_WD_CTL2)]                    = RD_WR_REG,
	[WCD9378_REG(WCD9378_RAMP_CTL)]                       = RD_WR_REG,
	[WCD9378_REG(WCD9378_ACT_DET_CTL)]                    = RD_WR_REG,
	[WCD9378_REG(WCD9378_ACT_DET_HOOKUP0)]                = RD_WR_REG,
	[WCD9378_REG(WCD9378_ACT_DET_HOOKUP1)]                = RD_WR_REG,
	[WCD9378_REG(WCD9378_ACT_DET_HOOKUP2)]                = RD_WR_REG,
	[WCD9378_REG(WCD9378_ACT_DET_DLY_BUF_EN)]             = RD_WR_REG,
	[WCD9378_REG(WCD9378_INTR_MODE)]                      = RD_WR_REG,
	[WCD9378_REG(WCD9378_INTR_STATUS_0)]                  = RD_WR_REG,
	[WCD9378_REG(WCD9378_INTR_STATUS_1)]                  = RD_WR_REG,
	[WCD9378_REG(WCD9378_INTR_STATUS_2)]                  = RD_WR_REG,
	[WCD9378_REG(WCD9378_INTR_STATUS_3)]                  = RD_WR_REG,
	[WCD9378_REG(WCD9378_INTR_MASK_0)]                    = RD_WR_REG,
	[WCD9378_REG(WCD9378_INTR_MASK_1)]                    = RD_WR_REG,
	[WCD9378_REG(WCD9378_INTR_MASK_2)]                    = RD_WR_REG,
	[WCD9378_REG(WCD9378_INTR_MASK_3)]                    = RD_WR_REG,
	[WCD9378_REG(WCD9378_INTR_SET_0)]                     = RD_WR_REG,
	[WCD9378_REG(WCD9378_INTR_SET_1)]                     = RD_WR_REG,
	[WCD9378_REG(WCD9378_INTR_SET_2)]                     = RD_WR_REG,
	[WCD9378_REG(WCD9378_INTR_SET_3)]                     = RD_WR_REG,
	[WCD9378_REG(WCD9378_INTR_TEST_0)]                    = RD_WR_REG,
	[WCD9378_REG(WCD9378_INTR_TEST_1)]                    = RD_WR_REG,
	[WCD9378_REG(WCD9378_INTR_TEST_2)]                    = RD_WR_REG,
	[WCD9378_REG(WCD9378_INTR_TEST_3)]                    = RD_WR_REG,
	[WCD9378_REG(WCD9378_TX_MODE_DBG_EN)]                 = RD_WR_REG,
	[WCD9378_REG(WCD9378_TX_MODE_DBG_0_1)]                = RD_WR_REG,
	[WCD9378_REG(WCD9378_TX_MODE_DBG_2_3)]                = RD_WR_REG,
	[WCD9378_REG(WCD9378_LB_IN_SEL_CTL)]                  = RD_WR_REG,
	[WCD9378_REG(WCD9378_LOOP_BACK_MODE)]                 = RD_WR_REG,
	[WCD9378_REG(WCD9378_SWR_DAC_TEST)]                   = RD_WR_REG,
	[WCD9378_REG(WCD9378_SWR_HM_TEST_RX_0)]               = RD_WR_REG,
	[WCD9378_REG(WCD9378_SWR_HM_TEST_TX_0)]               = RD_WR_REG,
	[WCD9378_REG(WCD9378_SWR_HM_TEST_RX_1)]               = RD_WR_REG,
	[WCD9378_REG(WCD9378_SWR_HM_TEST_TX_1)]               = RD_WR_REG,
	[WCD9378_REG(WCD9378_SWR_HM_TEST_0)]                  = RD_REG,
	[WCD9378_REG(WCD9378_PAD_CTL_SWR_0)]                  = RD_WR_REG,
	[WCD9378_REG(WCD9378_PAD_CTL_SWR_1)]                  = RD_WR_REG,
	[WCD9378_REG(WCD9378_I2C_CTL)]                        = RD_WR_REG,
	[WCD9378_REG(WCD9378_LEGACY_SW_MODE)]                 = RD_WR_REG,
	[WCD9378_REG(WCD9378_EFUSE_TEST_CTL_0)]               = RD_WR_REG,
	[WCD9378_REG(WCD9378_EFUSE_TEST_CTL_1)]               = RD_WR_REG,
	[WCD9378_REG(WCD9378_EFUSE_T_DATA_0)]                 = RD_REG,
	[WCD9378_REG(WCD9378_PAD_CTL_PDM_RX0)]                = RD_WR_REG,
	[WCD9378_REG(WCD9378_PAD_CTL_PDM_RX1)]                = RD_WR_REG,
	[WCD9378_REG(WCD9378_PAD_CTL_PDM_TX0)]                = RD_WR_REG,
	[WCD9378_REG(WCD9378_PAD_CTL_PDM_TX1)]                = RD_WR_REG,
	[WCD9378_REG(WCD9378_PAD_INP_DIS_0)]                  = RD_WR_REG,
	[WCD9378_REG(WCD9378_DRIVE_STRENGTH_0)]               = RD_WR_REG,
	[WCD9378_REG(WCD9378_DRIVE_STRENGTH_1)]               = RD_WR_REG,
	[WCD9378_REG(WCD9378_RX_DATA_EDGE_CTL)]               = RD_WR_REG,
	[WCD9378_REG(WCD9378_TX_DATA_EDGE_CTL)]               = RD_WR_REG,
	[WCD9378_REG(WCD9378_GPIO_MODE)]                      = RD_WR_REG,
	[WCD9378_REG(WCD9378_PIN_CTL_OE)]                     = RD_WR_REG,
	[WCD9378_REG(WCD9378_PIN_CTL_DATA_0)]                 = RD_WR_REG,
	[WCD9378_REG(WCD9378_PIN_STATUS_0)]                   = RD_REG,
	[WCD9378_REG(WCD9378_DIG_DEBUG_CTL)]                  = RD_WR_REG,
	[WCD9378_REG(WCD9378_DIG_DEBUG_EN)]                   = RD_WR_REG,
	[WCD9378_REG(WCD9378_ANA_CSR_DBG_ADD)]                = RD_WR_REG,
	[WCD9378_REG(WCD9378_ANA_CSR_DBG_CTL)]                = RD_WR_REG,
	[WCD9378_REG(WCD9378_SSP_DBG)]                        = RD_WR_REG,
	[WCD9378_REG(WCD9378_MODE_STATUS_0)]                  = RD_REG,
	[WCD9378_REG(WCD9378_MODE_STATUS_1)]                  = RD_REG,
	[WCD9378_REG(WCD9378_SPARE_0)]                        = RD_WR_REG,
	[WCD9378_REG(WCD9378_SPARE_1)]                        = RD_WR_REG,
	[WCD9378_REG(WCD9378_SPARE_2)]                        = RD_WR_REG,
	[WCD9378_REG(WCD9378_EFUSE_REG_0)]                    = RD_REG,
	[WCD9378_REG(WCD9378_EFUSE_REG_1)]                    = RD_REG,
	[WCD9378_REG(WCD9378_EFUSE_REG_2)]                    = RD_REG,
	[WCD9378_REG(WCD9378_EFUSE_REG_3)]                    = RD_REG,
	[WCD9378_REG(WCD9378_EFUSE_REG_4)]                    = RD_REG,
	[WCD9378_REG(WCD9378_EFUSE_REG_5)]                    = RD_REG,
	[WCD9378_REG(WCD9378_EFUSE_REG_6)]                    = RD_REG,
	[WCD9378_REG(WCD9378_EFUSE_REG_7)]                    = RD_REG,
	[WCD9378_REG(WCD9378_EFUSE_REG_8)]                    = RD_REG,
	[WCD9378_REG(WCD9378_EFUSE_REG_9)]                    = RD_REG,
	[WCD9378_REG(WCD9378_EFUSE_REG_10)]                   = RD_REG,
	[WCD9378_REG(WCD9378_EFUSE_REG_11)]                   = RD_REG,
	[WCD9378_REG(WCD9378_EFUSE_REG_12)]                   = RD_REG,
	[WCD9378_REG(WCD9378_EFUSE_REG_13)]                   = RD_REG,
	[WCD9378_REG(WCD9378_EFUSE_REG_14)]                   = RD_REG,
	[WCD9378_REG(WCD9378_EFUSE_REG_15)]                   = RD_REG,
	[WCD9378_REG(WCD9378_EFUSE_REG_16)]                   = RD_REG,
	[WCD9378_REG(WCD9378_EFUSE_REG_17)]                   = RD_REG,
	[WCD9378_REG(WCD9378_EFUSE_REG_18)]                   = RD_REG,
	[WCD9378_REG(WCD9378_EFUSE_REG_19)]                   = RD_REG,
	[WCD9378_REG(WCD9378_EFUSE_REG_20)]                   = RD_REG,
	[WCD9378_REG(WCD9378_EFUSE_REG_21)]                   = RD_REG,
	[WCD9378_REG(WCD9378_EFUSE_REG_22)]                   = RD_REG,
	[WCD9378_REG(WCD9378_EFUSE_REG_23)]                   = RD_REG,
	[WCD9378_REG(WCD9378_EFUSE_REG_24)]                   = RD_REG,
	[WCD9378_REG(WCD9378_EFUSE_REG_25)]                   = RD_REG,
	[WCD9378_REG(WCD9378_EFUSE_REG_26)]                   = RD_REG,
	[WCD9378_REG(WCD9378_EFUSE_REG_27)]                   = RD_REG,
	[WCD9378_REG(WCD9378_EFUSE_REG_28)]                   = RD_REG,
	[WCD9378_REG(WCD9378_EFUSE_REG_29)]                   = RD_REG,
	[WCD9378_REG(WCD9378_EFUSE_REG_30)]                   = RD_REG,
	[WCD9378_REG(WCD9378_EFUSE_REG_31)]                   = RD_REG,
	[WCD9378_REG(WCD9378_TX_REQ_FB_CTL_2)]                = RD_WR_REG,
	[WCD9378_REG(WCD9378_TX_REQ_FB_CTL_3)]                = RD_WR_REG,
	[WCD9378_REG(WCD9378_TX_REQ_FB_CTL_4)]                = RD_WR_REG,
	[WCD9378_REG(WCD9378_DEM_BYPASS_DATA0)]               = RD_WR_REG,
	[WCD9378_REG(WCD9378_DEM_BYPASS_DATA1)]               = RD_WR_REG,
	[WCD9378_REG(WCD9378_DEM_BYPASS_DATA2)]               = RD_WR_REG,
	[WCD9378_REG(WCD9378_DEM_BYPASS_DATA3)]               = RD_WR_REG,
	[WCD9378_REG(WCD9378_RX0_PCM_RAMP_STEP)]              = RD_WR_REG,
	[WCD9378_REG(WCD9378_RX0_DSD_RAMP_STEP)]              = RD_WR_REG,
	[WCD9378_REG(WCD9378_RX1_PCM_RAMP_STEP)]              = RD_WR_REG,
	[WCD9378_REG(WCD9378_RX1_DSD_RAMP_STEP)]              = RD_WR_REG,
	[WCD9378_REG(WCD9378_RX2_RAMP_STEP)]                  = RD_WR_REG,
	[WCD9378_REG(WCD9378_PLATFORM_CTL)]                   = RD_WR_REG,
	[WCD9378_REG(WCD9378_CLK_DIV_CFG)]                    = RD_WR_REG,
	[WCD9378_REG(WCD9378_DRE_DLY_VAL)]                    = RD_WR_REG,
	[WCD9378_REG(WCD9378_SYS_USAGE_CTRL)]                 = RD_WR_REG,
	[WCD9378_REG(WCD9378_SURGE_CTL)]                      = RD_WR_REG,
	[WCD9378_REG(WCD9378_SEQ_CTL)]                        = RD_WR_REG,
	[WCD9378_REG(WCD9378_HPH_UP_T0)]                      = RD_WR_REG,
	[WCD9378_REG(WCD9378_HPH_UP_T1)]                      = RD_WR_REG,
	[WCD9378_REG(WCD9378_HPH_UP_T2)]                      = RD_WR_REG,
	[WCD9378_REG(WCD9378_HPH_UP_T3)]                      = RD_WR_REG,
	[WCD9378_REG(WCD9378_HPH_UP_T4)]                      = RD_WR_REG,
	[WCD9378_REG(WCD9378_HPH_UP_T5)]                      = RD_WR_REG,
	[WCD9378_REG(WCD9378_HPH_UP_T6)]                      = RD_WR_REG,
	[WCD9378_REG(WCD9378_HPH_UP_T7)]                      = RD_WR_REG,
	[WCD9378_REG(WCD9378_HPH_UP_T8)]                      = RD_WR_REG,
	[WCD9378_REG(WCD9378_HPH_UP_T9)]                      = RD_WR_REG,
	[WCD9378_REG(WCD9378_HPH_UP_T10)]                     = RD_WR_REG,
	[WCD9378_REG(WCD9378_HPH_DN_T0)]                      = RD_WR_REG,
	[WCD9378_REG(WCD9378_HPH_DN_T1)]                      = RD_WR_REG,
	[WCD9378_REG(WCD9378_HPH_DN_T2)]                      = RD_WR_REG,
	[WCD9378_REG(WCD9378_HPH_DN_T3)]                      = RD_WR_REG,
	[WCD9378_REG(WCD9378_HPH_DN_T4)]                      = RD_WR_REG,
	[WCD9378_REG(WCD9378_HPH_DN_T5)]                      = RD_WR_REG,
	[WCD9378_REG(WCD9378_HPH_DN_T6)]                      = RD_WR_REG,
	[WCD9378_REG(WCD9378_HPH_DN_T7)]                      = RD_WR_REG,
	[WCD9378_REG(WCD9378_HPH_DN_T8)]                      = RD_WR_REG,
	[WCD9378_REG(WCD9378_HPH_DN_T9)]                      = RD_WR_REG,
	[WCD9378_REG(WCD9378_HPH_DN_T10)]                     = RD_WR_REG,
	[WCD9378_REG(WCD9378_HPH_UP_STAGE_LOC_0)]             = RD_WR_REG,
	[WCD9378_REG(WCD9378_HPH_UP_STAGE_LOC_1)]             = RD_WR_REG,
	[WCD9378_REG(WCD9378_HPH_UP_STAGE_LOC_2)]             = RD_WR_REG,
	[WCD9378_REG(WCD9378_HPH_UP_STAGE_LOC_3)]             = RD_WR_REG,
	[WCD9378_REG(WCD9378_HPH_UP_STAGE_LOC_4)]             = RD_WR_REG,
	[WCD9378_REG(WCD9378_HPH_UP_STAGE_LOC_5)]             = RD_WR_REG,
	[WCD9378_REG(WCD9378_HPH_UP_STAGE_LOC_6)]             = RD_WR_REG,
	[WCD9378_REG(WCD9378_HPH_UP_STAGE_LOC_7)]             = RD_WR_REG,
	[WCD9378_REG(WCD9378_HPH_UP_STAGE_LOC_8)]             = RD_WR_REG,
	[WCD9378_REG(WCD9378_HPH_UP_STAGE_LOC_9)]             = RD_WR_REG,
	[WCD9378_REG(WCD9378_HPH_UP_STAGE_LOC_10)]            = RD_WR_REG,
	[WCD9378_REG(WCD9378_HPH_DN_STAGE_LOC_0)]             = RD_WR_REG,
	[WCD9378_REG(WCD9378_HPH_DN_STAGE_LOC_1)]             = RD_WR_REG,
	[WCD9378_REG(WCD9378_HPH_DN_STAGE_LOC_2)]             = RD_WR_REG,
	[WCD9378_REG(WCD9378_HPH_DN_STAGE_LOC_3)]             = RD_WR_REG,
	[WCD9378_REG(WCD9378_HPH_DN_STAGE_LOC_4)]             = RD_WR_REG,
	[WCD9378_REG(WCD9378_HPH_DN_STAGE_LOC_5)]             = RD_WR_REG,
	[WCD9378_REG(WCD9378_HPH_DN_STAGE_LOC_6)]             = RD_WR_REG,
	[WCD9378_REG(WCD9378_HPH_DN_STAGE_LOC_7)]             = RD_WR_REG,
	[WCD9378_REG(WCD9378_HPH_DN_STAGE_LOC_8)]             = RD_WR_REG,
	[WCD9378_REG(WCD9378_HPH_DN_STAGE_LOC_9)]             = RD_WR_REG,
	[WCD9378_REG(WCD9378_HPH_DN_STAGE_LOC_10)]            = RD_WR_REG,
	[WCD9378_REG(WCD9378_SA_UP_T0)]                       = RD_WR_REG,
	[WCD9378_REG(WCD9378_SA_UP_T1)]                       = RD_WR_REG,
	[WCD9378_REG(WCD9378_SA_UP_T2)]                       = RD_WR_REG,
	[WCD9378_REG(WCD9378_SA_UP_T3)]                       = RD_WR_REG,
	[WCD9378_REG(WCD9378_SA_UP_T4)]                       = RD_WR_REG,
	[WCD9378_REG(WCD9378_SA_UP_T5)]                       = RD_WR_REG,
	[WCD9378_REG(WCD9378_SA_UP_T6)]                       = RD_WR_REG,
	[WCD9378_REG(WCD9378_SA_UP_T7)]                       = RD_WR_REG,
	[WCD9378_REG(WCD9378_SA_DN_T0)]                       = RD_WR_REG,
	[WCD9378_REG(WCD9378_SA_DN_T1)]                       = RD_WR_REG,
	[WCD9378_REG(WCD9378_SA_DN_T2)]                       = RD_WR_REG,
	[WCD9378_REG(WCD9378_SA_DN_T3)]                       = RD_WR_REG,
	[WCD9378_REG(WCD9378_SA_DN_T4)]                       = RD_WR_REG,
	[WCD9378_REG(WCD9378_SA_DN_T5)]                       = RD_WR_REG,
	[WCD9378_REG(WCD9378_SA_DN_T6)]                       = RD_WR_REG,
	[WCD9378_REG(WCD9378_SA_DN_T7)]                       = RD_WR_REG,
	[WCD9378_REG(WCD9378_SA_UP_STAGE_LOC_0)]              = RD_WR_REG,
	[WCD9378_REG(WCD9378_SA_UP_STAGE_LOC_1)]              = RD_WR_REG,
	[WCD9378_REG(WCD9378_SA_UP_STAGE_LOC_2)]              = RD_WR_REG,
	[WCD9378_REG(WCD9378_SA_UP_STAGE_LOC_3)]              = RD_WR_REG,
	[WCD9378_REG(WCD9378_SA_UP_STAGE_LOC_4)]              = RD_WR_REG,
	[WCD9378_REG(WCD9378_SA_UP_STAGE_LOC_5)]              = RD_WR_REG,
	[WCD9378_REG(WCD9378_SA_UP_STAGE_LOC_6)]              = RD_WR_REG,
	[WCD9378_REG(WCD9378_SA_UP_STAGE_LOC_7)]              = RD_WR_REG,
	[WCD9378_REG(WCD9378_SA_DN_STAGE_LOC_0)]              = RD_WR_REG,
	[WCD9378_REG(WCD9378_SA_DN_STAGE_LOC_1)]              = RD_WR_REG,
	[WCD9378_REG(WCD9378_SA_DN_STAGE_LOC_2)]              = RD_WR_REG,
	[WCD9378_REG(WCD9378_SA_DN_STAGE_LOC_3)]              = RD_WR_REG,
	[WCD9378_REG(WCD9378_SA_DN_STAGE_LOC_4)]              = RD_WR_REG,
	[WCD9378_REG(WCD9378_SA_DN_STAGE_LOC_5)]              = RD_WR_REG,
	[WCD9378_REG(WCD9378_SA_DN_STAGE_LOC_6)]              = RD_WR_REG,
	[WCD9378_REG(WCD9378_SA_DN_STAGE_LOC_7)]              = RD_WR_REG,
	[WCD9378_REG(WCD9378_TX0_UP_T0)]                      = RD_WR_REG,
	[WCD9378_REG(WCD9378_TX0_UP_T1)]                      = RD_WR_REG,
	[WCD9378_REG(WCD9378_TX0_UP_T2)]                      = RD_WR_REG,
	[WCD9378_REG(WCD9378_TX0_UP_T3)]                      = RD_WR_REG,
	[WCD9378_REG(WCD9378_TX0_DN_T0)]                      = RD_WR_REG,
	[WCD9378_REG(WCD9378_TX0_DN_T1)]                      = RD_WR_REG,
	[WCD9378_REG(WCD9378_TX0_DN_T2)]                      = RD_WR_REG,
	[WCD9378_REG(WCD9378_TX0_DN_T3)]                      = RD_WR_REG,
	[WCD9378_REG(WCD9378_TX0_UP_STAGE_LOC_0)]             = RD_WR_REG,
	[WCD9378_REG(WCD9378_TX0_UP_STAGE_LOC_1)]             = RD_WR_REG,
	[WCD9378_REG(WCD9378_TX0_UP_STAGE_LOC_2)]             = RD_WR_REG,
	[WCD9378_REG(WCD9378_TX0_UP_STAGE_LOC_3)]             = RD_WR_REG,
	[WCD9378_REG(WCD9378_TX0_DN_STAGE_LOC_0)]             = RD_WR_REG,
	[WCD9378_REG(WCD9378_TX0_DN_STAGE_LOC_1)]             = RD_WR_REG,
	[WCD9378_REG(WCD9378_TX0_DN_STAGE_LOC_2)]             = RD_WR_REG,
	[WCD9378_REG(WCD9378_TX0_DN_STAGE_LOC_3)]             = RD_WR_REG,
	[WCD9378_REG(WCD9378_TX1_UP_T0)]                      = RD_WR_REG,
	[WCD9378_REG(WCD9378_TX1_UP_T1)]                      = RD_WR_REG,
	[WCD9378_REG(WCD9378_TX1_UP_T2)]                      = RD_WR_REG,
	[WCD9378_REG(WCD9378_TX1_UP_T3)]                      = RD_WR_REG,
	[WCD9378_REG(WCD9378_TX1_DN_T0)]                      = RD_WR_REG,
	[WCD9378_REG(WCD9378_TX1_DN_T1)]                      = RD_WR_REG,
	[WCD9378_REG(WCD9378_TX1_DN_T2)]                      = RD_WR_REG,
	[WCD9378_REG(WCD9378_TX1_DN_T3)]                      = RD_WR_REG,
	[WCD9378_REG(WCD9378_TX1_UP_STAGE_LOC_0)]             = RD_WR_REG,
	[WCD9378_REG(WCD9378_TX1_UP_STAGE_LOC_1)]             = RD_WR_REG,
	[WCD9378_REG(WCD9378_TX1_UP_STAGE_LOC_2)]             = RD_WR_REG,
	[WCD9378_REG(WCD9378_TX1_UP_STAGE_LOC_3)]             = RD_WR_REG,
	[WCD9378_REG(WCD9378_TX1_DN_STAGE_LOC_0)]             = RD_WR_REG,
	[WCD9378_REG(WCD9378_TX1_DN_STAGE_LOC_1)]             = RD_WR_REG,
	[WCD9378_REG(WCD9378_TX1_DN_STAGE_LOC_2)]             = RD_WR_REG,
	[WCD9378_REG(WCD9378_TX1_DN_STAGE_LOC_3)]             = RD_WR_REG,
	[WCD9378_REG(WCD9378_TX2_UP_T0)]                      = RD_WR_REG,
	[WCD9378_REG(WCD9378_TX2_UP_T1)]                      = RD_WR_REG,
	[WCD9378_REG(WCD9378_TX2_UP_T2)]                      = RD_WR_REG,
	[WCD9378_REG(WCD9378_TX2_UP_T3)]                      = RD_WR_REG,
	[WCD9378_REG(WCD9378_TX2_DN_T0)]                      = RD_WR_REG,
	[WCD9378_REG(WCD9378_TX2_DN_T1)]                      = RD_WR_REG,
	[WCD9378_REG(WCD9378_TX2_DN_T2)]                      = RD_WR_REG,
	[WCD9378_REG(WCD9378_TX2_DN_T3)]                      = RD_WR_REG,
	[WCD9378_REG(WCD9378_TX2_UP_STAGE_LOC_0)]             = RD_WR_REG,
	[WCD9378_REG(WCD9378_TX2_UP_STAGE_LOC_1)]             = RD_WR_REG,
	[WCD9378_REG(WCD9378_TX2_UP_STAGE_LOC_2)]             = RD_WR_REG,
	[WCD9378_REG(WCD9378_TX2_UP_STAGE_LOC_3)]             = RD_WR_REG,
	[WCD9378_REG(WCD9378_TX2_DN_STAGE_LOC_0)]             = RD_WR_REG,
	[WCD9378_REG(WCD9378_TX2_DN_STAGE_LOC_1)]             = RD_WR_REG,
	[WCD9378_REG(WCD9378_TX2_DN_STAGE_LOC_2)]             = RD_WR_REG,
	[WCD9378_REG(WCD9378_TX2_DN_STAGE_LOC_3)]             = RD_WR_REG,
	[WCD9378_REG(WCD9378_SEQ_HPH_STAT)]                   = RD_REG,
	[WCD9378_REG(WCD9378_SEQ_SA_STAT)]                    = RD_REG,
	[WCD9378_REG(WCD9378_SEQ_TX0_STAT)]                   = RD_REG,
	[WCD9378_REG(WCD9378_SEQ_TX1_STAT)]                   = RD_REG,
	[WCD9378_REG(WCD9378_SEQ_TX2_STAT)]                   = RD_REG,
	[WCD9378_REG(WCD9378_MICB_REMAP_TABLE_VAL_0)]         = RD_WR_REG,
	[WCD9378_REG(WCD9378_MICB_REMAP_TABLE_VAL_1)]         = RD_WR_REG,
	[WCD9378_REG(WCD9378_MICB_REMAP_TABLE_VAL_2)]         = RD_WR_REG,
	[WCD9378_REG(WCD9378_MICB_REMAP_TABLE_VAL_3)]         = RD_WR_REG,
	[WCD9378_REG(WCD9378_MICB_REMAP_TABLE_VAL_4)]         = RD_WR_REG,
	[WCD9378_REG(WCD9378_MICB_REMAP_TABLE_VAL_5)]         = RD_WR_REG,
	[WCD9378_REG(WCD9378_MICB_REMAP_TABLE_VAL_6)]         = RD_WR_REG,
	[WCD9378_REG(WCD9378_MICB_REMAP_TABLE_VAL_7)]         = RD_WR_REG,
	[WCD9378_REG(WCD9378_MICB_REMAP_TABLE_VAL_8)]         = RD_WR_REG,
	[WCD9378_REG(WCD9378_MICB_REMAP_TABLE_VAL_9)]         = RD_WR_REG,
	[WCD9378_REG(WCD9378_MICB_REMAP_TABLE_VAL_10)]        = RD_WR_REG,
	[WCD9378_REG(WCD9378_MICB_REMAP_TABLE_VAL_11)]        = RD_WR_REG,
	[WCD9378_REG(WCD9378_MICB_REMAP_TABLE_VAL_12)]        = RD_WR_REG,
	[WCD9378_REG(WCD9378_MICB_REMAP_TABLE_VAL_13)]        = RD_WR_REG,
	[WCD9378_REG(WCD9378_MICB_REMAP_TABLE_VAL_14)]        = RD_WR_REG,
	[WCD9378_REG(WCD9378_MICB_REMAP_TABLE_VAL_15)]        = RD_WR_REG,
	[WCD9378_REG(WCD9378_SM0_MB_SEL)]                     = RD_WR_REG,
	[WCD9378_REG(WCD9378_SM1_MB_SEL)]                     = RD_WR_REG,
	[WCD9378_REG(WCD9378_SM2_MB_SEL)]                     = RD_WR_REG,
	[WCD9378_REG(WCD9378_MB_PULLUP_EN)]                   = RD_WR_REG,
	[WCD9378_REG(WCD9378_BYP_EN_CTL0)]                    = RD_WR_REG,
	[WCD9378_REG(WCD9378_BYP_EN_CTL1)]                    = RD_WR_REG,
	[WCD9378_REG(WCD9378_BYP_EN_CTL2)]                    = RD_WR_REG,
	[WCD9378_REG(WCD9378_SEQ_OVRRIDE_CTL0)]               = RD_WR_REG,
	[WCD9378_REG(WCD9378_SEQ_OVRRIDE_CTL1)]               = RD_WR_REG,
	[WCD9378_REG(WCD9378_SEQ_OVRRIDE_CTL2)]               = RD_WR_REG,
	[WCD9378_REG(WCD9378_HPH_SEQ_OVRRIDE_CTL0)]           = RD_WR_REG,
	[WCD9378_REG(WCD9378_HPH_SEQ_OVRRIDE_CTL1)]           = RD_WR_REG,
	[WCD9378_REG(WCD9378_SA_SEQ_OVRRIDE_CTL)]             = RD_WR_REG,
	[WCD9378_REG(WCD9378_TX0_SEQ_OVRRIDE_CTL)]            = RD_WR_REG,
	[WCD9378_REG(WCD9378_TX1_SEQ_OVRRIDE_CTL)]            = RD_WR_REG,
	[WCD9378_REG(WCD9378_TX2_SEQ_OVRRIDE_CTL)]            = RD_WR_REG,
	[WCD9378_REG(WCD9378_FORCE_CTL)]                      = RD_WR_REG,
	[WCD9378_REG(WCD9378_DEVICE_DET)]                     = RD_WR_REG,
	[WCD9378_REG(WCD9378_TYPE0_WRAP_OSCNX_TPRESS_MIN_0)]  = RD_WR_REG,
	[WCD9378_REG(WCD9378_TYPE0_WRAP_OSCNX_TPRESS_MAX_0)]  = RD_WR_REG,
	[WCD9378_REG(WCD9378_TYPE0_WRAP_OSCNX_TRELEASE_MIN_0)] = RD_WR_REG,
	[WCD9378_REG(WCD9378_TYPE0_WRAP_OSCNX_TRELEASE_MAX_0)] = RD_WR_REG,
	[WCD9378_REG(WCD9378_TYPE0_WRAP_OSCNX_HDL_BT_ASSIGN_0)] = RD_WR_REG,
	[WCD9378_REG(WCD9378_TYPE0_WRAP_OSCNX_OUTPUT_SEL_0)]  = RD_WR_REG,
	[WCD9378_REG(WCD9378_TYPE0_WRAP_OSCNX_TPRESS_MIN_1)]  = RD_WR_REG,
	[WCD9378_REG(WCD9378_TYPE0_WRAP_OSCNX_TPRESS_MAX_1)]  = RD_WR_REG,
	[WCD9378_REG(WCD9378_TYPE0_WRAP_OSCNX_TRELEASE_MIN_1)] = RD_WR_REG,
	[WCD9378_REG(WCD9378_TYPE0_WRAP_OSCNX_TRELEASE_MAX_1)] = RD_WR_REG,
	[WCD9378_REG(WCD9378_TYPE0_WRAP_OSCNX_HDL_BT_ASSIGN_1)] = RD_WR_REG,
	[WCD9378_REG(WCD9378_TYPE0_WRAP_OSCNX_OUTPUT_SEL_1)]  = RD_WR_REG,
	[WCD9378_REG(WCD9378_TYPE0_WRAP_OSCNX_TPRESS_MIN_2)]  = RD_WR_REG,
	[WCD9378_REG(WCD9378_TYPE0_WRAP_OSCNX_TPRESS_MAX_2)]  = RD_WR_REG,
	[WCD9378_REG(WCD9378_TYPE0_WRAP_OSCNX_TRELEASE_MIN_2)] = RD_WR_REG,
	[WCD9378_REG(WCD9378_TYPE0_WRAP_OSCNX_TRELEASE_MAX_2)] = RD_WR_REG,
	[WCD9378_REG(WCD9378_TYPE0_WRAP_OSCNX_HDL_BT_ASSIGN_2)] = RD_WR_REG,
	[WCD9378_REG(WCD9378_TYPE0_WRAP_OSCNX_OUTPUT_SEL_2)]  = RD_WR_REG,
	[WCD9378_REG(WCD9378_TYPE0_WRAP_OSCNX_TPRESS_MIN_3)]  = RD_WR_REG,
	[WCD9378_REG(WCD9378_TYPE0_WRAP_OSCNX_TPRESS_MAX_3)]  = RD_WR_REG,
	[WCD9378_REG(WCD9378_TYPE0_WRAP_OSCNX_TRELEASE_MIN_3)] = RD_WR_REG,
	[WCD9378_REG(WCD9378_TYPE0_WRAP_OSCNX_TRELEASE_MAX_3)] = RD_WR_REG,
	[WCD9378_REG(WCD9378_TYPE0_WRAP_OSCNX_HDL_BT_ASSIGN_3)] = RD_WR_REG,
	[WCD9378_REG(WCD9378_TYPE0_WRAP_OSCNX_OUTPUT_SEL_3)]  = RD_WR_REG,
	[WCD9378_REG(WCD9378_TYPE1_WRAP_OSCNX_TPRESS_MIN_0)]  = RD_WR_REG,
	[WCD9378_REG(WCD9378_TYPE1_WRAP_OSCNX_TPRESS_MAX_0)]  = RD_WR_REG,
	[WCD9378_REG(WCD9378_TYPE1_WRAP_OSCNX_TRELEASE_MIN_0)] = RD_WR_REG,
	[WCD9378_REG(WCD9378_TYPE1_WRAP_OSCNX_TRELEASE_MAX_0)] = RD_WR_REG,
	[WCD9378_REG(WCD9378_TYPE1_WRAP_OSCNX_HDL_BT_ASSIGN_0)] = RD_WR_REG,
	[WCD9378_REG(WCD9378_TYPE1_WRAP_OSCNX_OUTPUT_SEL_0)]  = RD_WR_REG,
	[WCD9378_REG(WCD9378_TYPE1_WRAP_HOLD_TPRESS_MIN_0)]   = RD_WR_REG,
	[WCD9378_REG(WCD9378_TYPE1_WRAP_HOLD_TRELEASE_MIN_0)] = RD_WR_REG,
	[WCD9378_REG(WCD9378_TYPE1_WRAP_HOLD_HDL_BT_ASSIGN_0)] = RD_WR_REG,
	[WCD9378_REG(WCD9378_TYPE1_WRAP_RO_TDEBOUNCE_0)]      = RD_WR_REG,
	[WCD9378_REG(WCD9378_TYPE1_WRAP_RO_HDL_BT_ASSIGN_0)]  = RD_WR_REG,
	[WCD9378_REG(WCD9378_TYPE1_WRAP_RTC_OOC_SEL_0)]       = RD_WR_REG,
	[WCD9378_REG(WCD9378_TYPE1_WRAP_OSCNX_TPRESS_MIN_1)]  = RD_WR_REG,
	[WCD9378_REG(WCD9378_TYPE1_WRAP_OSCNX_TPRESS_MAX_1)]  = RD_WR_REG,
	[WCD9378_REG(WCD9378_TYPE1_WRAP_OSCNX_TRELEASE_MIN_1)] = RD_WR_REG,
	[WCD9378_REG(WCD9378_TYPE1_WRAP_OSCNX_TRELEASE_MAX_1)] = RD_WR_REG,
	[WCD9378_REG(WCD9378_TYPE1_WRAP_OSCNX_HDL_BT_ASSIGN_1)] = RD_WR_REG,
	[WCD9378_REG(WCD9378_TYPE1_WRAP_OSCNX_OUTPUT_SEL_1)]  = RD_WR_REG,
	[WCD9378_REG(WCD9378_TYPE1_WRAP_HOLD_TPRESS_MIN_1)]   = RD_WR_REG,
	[WCD9378_REG(WCD9378_TYPE1_WRAP_HOLD_TRELEASE_MIN_1)] = RD_WR_REG,
	[WCD9378_REG(WCD9378_TYPE1_WRAP_HOLD_HDL_BT_ASSIGN_1)] = RD_WR_REG,
	[WCD9378_REG(WCD9378_TYPE1_WRAP_RO_TDEBOUNCE_1)]      = RD_WR_REG,
	[WCD9378_REG(WCD9378_TYPE1_WRAP_RO_HDL_BT_ASSIGN_1)]  = RD_WR_REG,
	[WCD9378_REG(WCD9378_TYPE1_WRAP_RTC_OOC_SEL_1)]       = RD_WR_REG,
	[WCD9378_REG(WCD9378_TYPE1_WRAP_OSCNX_TPRESS_MIN_2)]  = RD_WR_REG,
	[WCD9378_REG(WCD9378_TYPE1_WRAP_OSCNX_TPRESS_MAX_2)]  = RD_WR_REG,
	[WCD9378_REG(WCD9378_TYPE1_WRAP_OSCNX_TRELEASE_MIN_2)] = RD_WR_REG,
	[WCD9378_REG(WCD9378_TYPE1_WRAP_OSCNX_TRELEASE_MAX_2)] = RD_WR_REG,
	[WCD9378_REG(WCD9378_TYPE1_WRAP_OSCNX_HDL_BT_ASSIGN_2)] = RD_WR_REG,
	[WCD9378_REG(WCD9378_TYPE1_WRAP_OSCNX_OUTPUT_SEL_2)]  = RD_WR_REG,
	[WCD9378_REG(WCD9378_TYPE1_WRAP_HOLD_TPRESS_MIN_2)]   = RD_WR_REG,
	[WCD9378_REG(WCD9378_TYPE1_WRAP_HOLD_TRELEASE_MIN_2)] = RD_WR_REG,
	[WCD9378_REG(WCD9378_TYPE1_WRAP_HOLD_HDL_BT_ASSIGN_2)] = RD_WR_REG,
	[WCD9378_REG(WCD9378_TYPE1_WRAP_RO_TDEBOUNCE_2)]      = RD_WR_REG,
	[WCD9378_REG(WCD9378_TYPE1_WRAP_RO_HDL_BT_ASSIGN_2)]  = RD_WR_REG,
	[WCD9378_REG(WCD9378_TYPE1_WRAP_RTC_OOC_SEL_2)]       = RD_WR_REG,
	[WCD9378_REG(WCD9378_TYPE1_WRAP_OSCNX_TPRESS_MIN_3)]  = RD_WR_REG,
	[WCD9378_REG(WCD9378_TYPE1_WRAP_OSCNX_TPRESS_MAX_3)]  = RD_WR_REG,
	[WCD9378_REG(WCD9378_TYPE1_WRAP_OSCNX_TRELEASE_MIN_3)] = RD_WR_REG,
	[WCD9378_REG(WCD9378_TYPE1_WRAP_OSCNX_TRELEASE_MAX_3)] = RD_WR_REG,
	[WCD9378_REG(WCD9378_TYPE1_WRAP_OSCNX_HDL_BT_ASSIGN_3)] = RD_WR_REG,
	[WCD9378_REG(WCD9378_TYPE1_WRAP_OSCNX_OUTPUT_SEL_3)]  = RD_WR_REG,
	[WCD9378_REG(WCD9378_TYPE1_WRAP_HOLD_TPRESS_MIN_3)]   = RD_WR_REG,
	[WCD9378_REG(WCD9378_TYPE1_WRAP_HOLD_TRELEASE_MIN_3)] = RD_WR_REG,
	[WCD9378_REG(WCD9378_TYPE1_WRAP_HOLD_HDL_BT_ASSIGN_3)] = RD_WR_REG,
	[WCD9378_REG(WCD9378_TYPE1_WRAP_RO_TDEBOUNCE_3)]      = RD_WR_REG,
	[WCD9378_REG(WCD9378_TYPE1_WRAP_RO_HDL_BT_ASSIGN_3)]  = RD_WR_REG,
	[WCD9378_REG(WCD9378_TYPE1_WRAP_RTC_OOC_SEL_3)]       = RD_WR_REG,
	[WCD9378_REG(WCD9378_SDCA_MESSAGE_GATE)]              = RD_WR_REG,
	[WCD9378_REG(WCD9378_MBHC_DATA_IN_EDGE)]              = RD_WR_REG,
	[WCD9378_REG(WCD9378_MBHC_RESET)]                     = RD_WR_REG,
	[WCD9378_REG(WCD9378_MBHC_DEBUG)]                     = RD_WR_REG,
	[WCD9378_REG(WCD9378_MBHC_DEBUG_UMP_0)]               = RD_REG,
	[WCD9378_REG(WCD9378_MBHC_DEBUG_UMP_1)]               = RD_REG,
	[WCD9378_REG(WCD9378_MBHC_DEBUG_UMP_2)]               = RD_REG,
	[WCD9378_REG(WCD9378_HID_FUNC_EXT_ID_0)]              = RD_REG,
	[WCD9378_REG(WCD9378_HID_FUNC_EXT_ID_1)]              = RD_REG,
	[WCD9378_REG(WCD9378_HID_FUNC_EXT_VER)]               = RD_REG,
	[WCD9378_REG(WCD9378_HID_FUNC_STAT)]                  = RD_WR_REG,
	[WCD9378_REG(WCD9378_HID_CUR_OWNER)]                  = RD_WR_REG,
	[WCD9378_REG(WCD9378_HID_MSG_OFFSET)]                 = RD_REG,
	[WCD9378_REG(WCD9378_HID_MSG_LENGTH)]                 = RD_REG,
	[WCD9378_REG(WCD9378_HID_DEV_MANU_ID_0)]              = RD_REG,
	[WCD9378_REG(WCD9378_HID_DEV_MANU_ID_1)]              = RD_REG,
	[WCD9378_REG(WCD9378_HID_DEV_PART_ID_0)]              = RD_REG,
	[WCD9378_REG(WCD9378_HID_DEV_PART_ID_1)]              = RD_REG,
	[WCD9378_REG(WCD9378_HID_DEV_VER)]                    = RD_REG,
	[WCD9378_REG(WCD9378_SMP_AMP_FUNC_EXT_ID_0)]          = RD_REG,
	[WCD9378_REG(WCD9378_SMP_AMP_FUNC_EXT_ID_1)]          = RD_REG,
	[WCD9378_REG(WCD9378_SMP_AMP_FUNC_EXT_VER)]           = RD_REG,
	[WCD9378_REG(WCD9378_XU22_BYP)]                       = RD_WR_REG,
	[WCD9378_REG(WCD9378_PDE22_REQ_PS)]                   = RD_WR_REG,
	[WCD9378_REG(WCD9378_FU23_MUTE)]                      = RD_WR_REG,
	[WCD9378_REG(WCD9378_PDE23_REQ_PS)]                   = RD_WR_REG,
	[WCD9378_REG(WCD9378_SMP_AMP_FUNC_STAT)]              = RD_WR_REG,
	[WCD9378_REG(WCD9378_FUNC_ACT)]                       = RD_WR_REG,
	[WCD9378_REG(WCD9378_PDE22_ACT_PS)]                   = RD_REG,
	[WCD9378_REG(WCD9378_SAPU29_PROT_MODE)]               = RD_REG,
	[WCD9378_REG(WCD9378_SAPU29_PROT_STAT)]               = RD_REG,
	[WCD9378_REG(WCD9378_PDE23_ACT_PS)]                   = RD_REG,
	[WCD9378_REG(WCD9378_SMP_AMP_DEV_MANU_ID_0)]          = RD_REG,
	[WCD9378_REG(WCD9378_SMP_AMP_DEV_MANU_ID_1)]          = RD_REG,
	[WCD9378_REG(WCD9378_SMP_AMP_DEV_PART_ID_0)]          = RD_REG,
	[WCD9378_REG(WCD9378_SMP_AMP_DEV_PART_ID_1)]          = RD_REG,
	[WCD9378_REG(WCD9378_SMP_AMP_DEV_VER)]                = RD_REG,
	[WCD9378_REG(WCD9378_CMT_GRP_MASK)]                   = RD_WR_REG,
	[WCD9378_REG(WCD9378_SMP_JACK_FUNC_EXT_ID_0)]         = RD_REG,
	[WCD9378_REG(WCD9378_SMP_JACK_FUNC_EXT_ID_1)]         = RD_REG,
	[WCD9378_REG(WCD9378_SMP_JACK_FUNC_EXT_VER)]          = RD_REG,
	[WCD9378_REG(WCD9378_IT41_USAGE)]                     = RD_WR_REG,
	[WCD9378_REG(WCD9378_XU42_BYP)]                       = RD_WR_REG,
	[WCD9378_REG(WCD9378_PDE42_REQ_PS)]                   = RD_WR_REG,
	[WCD9378_REG(WCD9378_FU42_MUTE_CH1)]                  = RD_WR_REG,
	[WCD9378_REG(WCD9378_FU42_MUTE_CH2)]                  = RD_WR_REG,
	[WCD9378_REG(WCD9378_FU42_CH_VOL_CH1)]                = RD_WR_REG,
	[WCD9378_REG(WCD9378_FU42_CH_VOL_CH2)]                = RD_WR_REG,
	[WCD9378_REG(WCD9378_SU43_SELECTOR)]                  = RD_REG,
	[WCD9378_REG(WCD9378_SU45_SELECTOR)]                  = RD_REG,
	[WCD9378_REG(WCD9378_PDE47_REQ_PS)]                   = RD_WR_REG,
	[WCD9378_REG(WCD9378_GE35_SEL_MODE)]                  = RD_WR_REG,
	[WCD9378_REG(WCD9378_GE35_DET_MODE)]                  = RD_REG,
	[WCD9378_REG(WCD9378_IT31_MICB)]                      = RD_WR_REG,
	[WCD9378_REG(WCD9378_IT31_USAGE)]                     = RD_WR_REG,
	[WCD9378_REG(WCD9378_PDE34_REQ_PS)]                   = RD_WR_REG,
	[WCD9378_REG(WCD9378_SU45_TX_SELECTOR)]               = RD_REG,
	[WCD9378_REG(WCD9378_XU36_BYP)]                       = RD_WR_REG,
	[WCD9378_REG(WCD9378_PDE36_REQ_PS)]                   = RD_WR_REG,
	[WCD9378_REG(WCD9378_OT36_USAGE)]                     = RD_REG,
	[WCD9378_REG(WCD9378_SMP_JACK_FUNC_STAT)]             = RD_WR_REG,
	[WCD9378_REG(WCD9378_SMP_JACK_FUNC_ACT)]              = RD_WR_REG,
	[WCD9378_REG(WCD9378_PDE42_ACT_PS)]                   = RD_REG,
	[WCD9378_REG(WCD9378_PDE47_ACT_PS)]                   = RD_REG,
	[WCD9378_REG(WCD9378_PDE34_ACT_PS)]                   = RD_REG,
	[WCD9378_REG(WCD9378_PDE36_ACT_PS)]                   = RD_REG,
	[WCD9378_REG(WCD9378_SMP_JACK_DEV_MANU_ID_0)]         = RD_REG,
	[WCD9378_REG(WCD9378_SMP_JACK_DEV_MANU_ID_1)]         = RD_REG,
	[WCD9378_REG(WCD9378_SMP_JACK_DEV_PART_ID_0)]         = RD_REG,
	[WCD9378_REG(WCD9378_SMP_JACK_DEV_PART_ID_1)]         = RD_REG,
	[WCD9378_REG(WCD9378_SMP_JACK_DEV_VER)]               = RD_REG,
	[WCD9378_REG(WCD9378_SMP_MIC_CTRL0_FUNC_EXT_ID_0)]    = RD_REG,
	[WCD9378_REG(WCD9378_SMP_MIC_CTRL0_FUNC_EXT_ID_1)]    = RD_REG,
	[WCD9378_REG(WCD9378_SMP_MIC_CTRL0_FUNC_EXT_VER)]     = RD_REG,
	[WCD9378_REG(WCD9378_IT11_MICB)]                      = RD_WR_REG,
	[WCD9378_REG(WCD9378_IT11_USAGE)]                     = RD_WR_REG,
	[WCD9378_REG(WCD9378_PDE11_REQ_PS)]                   = RD_WR_REG,
	[WCD9378_REG(WCD9378_OT10_USAGE)]                     = RD_REG,
	[WCD9378_REG(WCD9378_SMP_MIC_CTRL0_FUNC_STAT)]        = RD_WR_REG,
	[WCD9378_REG(WCD9378_SMP_MIC_CTRL0_FUNC_ACT)]         = RD_WR_REG,
	[WCD9378_REG(WCD9378_PDE11_ACT_PS)]                   = RD_REG,
	[WCD9378_REG(WCD9378_SMP_MIC_CTRL0_DEV_MANU_ID_0)]    = RD_REG,
	[WCD9378_REG(WCD9378_SMP_MIC_CTRL0_DEV_MANU_ID_1)]    = RD_REG,
	[WCD9378_REG(WCD9378_SMP_MIC_CTRL0_DEV_PART_ID_0)]    = RD_REG,
	[WCD9378_REG(WCD9378_SMP_MIC_CTRL0_DEV_PART_ID_1)]    = RD_REG,
	[WCD9378_REG(WCD9378_SMP_MIC_CTRL0_DEV_VER)]          = RD_REG,
	[WCD9378_REG(WCD9378_SMP_MIC_CTRL1_FUNC_EXT_ID_0)]    = RD_REG,
	[WCD9378_REG(WCD9378_SMP_MIC_CTRL1_FUNC_EXT_ID_1)]    = RD_REG,
	[WCD9378_REG(WCD9378_SMP_MIC_CTRL1_FUNC_EXT_VER)]     = RD_REG,
	[WCD9378_REG(WCD9378_SMP_MIC_CTRL1_IT11_MICB)]        = RD_WR_REG,
	[WCD9378_REG(WCD9378_SMP_MIC_CTRL1_IT11_USAGE)]       = RD_WR_REG,
	[WCD9378_REG(WCD9378_SMP_MIC_CTRL1_PDE11_REQ_PS)]     = RD_WR_REG,
	[WCD9378_REG(WCD9378_SMP_MIC_CTRL1_OT10_USAGE)]       = RD_REG,
	[WCD9378_REG(WCD9378_SMP_MIC_CTRL1_FUNC_STAT)]        = RD_WR_REG,
	[WCD9378_REG(WCD9378_SMP_MIC_CTRL1_FUNC_ACT)]         = RD_WR_REG,
	[WCD9378_REG(WCD9378_SMP_MIC_CTRL1_PDE11_ACT_PS)]     = RD_REG,
	[WCD9378_REG(WCD9378_SMP_MIC_CTRL1_DEV_MANU_ID_0)]    = RD_REG,
	[WCD9378_REG(WCD9378_SMP_MIC_CTRL1_DEV_MANU_ID_1)]    = RD_REG,
	[WCD9378_REG(WCD9378_SMP_MIC_CTRL1_DEV_PART_ID_0)]    = RD_REG,
	[WCD9378_REG(WCD9378_SMP_MIC_CTRL1_DEV_PART_ID_1)]    = RD_REG,
	[WCD9378_REG(WCD9378_SMP_MIC_CTRL1_DEV_VER)]          = RD_REG,
	[WCD9378_REG(WCD9378_SMP_MIC_CTRL2_FUNC_EXT_ID_0)]    = RD_REG,
	[WCD9378_REG(WCD9378_SMP_MIC_CTRL2_FUNC_EXT_ID_1)]    = RD_REG,
	[WCD9378_REG(WCD9378_SMP_MIC_CTRL2_FUNC_EXT_VER)]     = RD_REG,
	[WCD9378_REG(WCD9378_SMP_MIC_CTRL2_IT11_MICB)]        = RD_WR_REG,
	[WCD9378_REG(WCD9378_SMP_MIC_CTRL2_IT11_USAGE)]       = RD_WR_REG,
	[WCD9378_REG(WCD9378_SMP_MIC_CTRL2_PDE11_REQ_PS)]     = RD_WR_REG,
	[WCD9378_REG(WCD9378_SMP_MIC_CTRL2_OT10_USAGE)]       = RD_REG,
	[WCD9378_REG(WCD9378_SMP_MIC_CTRL2_FUNC_STAT)]        = RD_WR_REG,
	[WCD9378_REG(WCD9378_SMP_MIC_CTRL2_FUNC_ACT)]         = RD_WR_REG,
	[WCD9378_REG(WCD9378_SMP_MIC_CTRL2_PDE11_ACT_PS)]     = RD_REG,
	[WCD9378_REG(WCD9378_SMP_MIC_CTRL2_DEV_MANU_ID_0)]    = RD_REG,
	[WCD9378_REG(WCD9378_SMP_MIC_CTRL2_DEV_MANU_ID_1)]    = RD_REG,
	[WCD9378_REG(WCD9378_SMP_MIC_CTRL2_DEV_PART_ID_0)]    = RD_REG,
	[WCD9378_REG(WCD9378_SMP_MIC_CTRL2_DEV_PART_ID_1)]    = RD_REG,
	[WCD9378_REG(WCD9378_SMP_MIC_CTRL2_DEV_VER)]          = RD_REG,
	[WCD9378_REG(WCD9378_REPORT_ID)]                      = RD_REG,
	[WCD9378_REG(WCD9378_MESSAGE0)]                       = RD_REG,
	[WCD9378_REG(WCD9378_MESSAGE1)]                       = RD_REG,
	[WCD9378_REG(WCD9378_MESSAGE2)]                       = RD_REG,
};

